---
title: <span class="badge builder"></span> ElasticsearchTopMetricsSettings
---
# <span class="badge builder"></span> ElasticsearchTopMetricsSettings

## Constructor

```python
ElasticsearchTopMetricsSettings()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.ElasticsearchTopMetricsSettings
```

### <span class="badge object-method"></span> metrics

```python
def metrics(metrics: list[str]) -> typing.Self
```

### <span class="badge object-method"></span> order

```python
def order(order: str) -> typing.Self
```

### <span class="badge object-method"></span> order_by

```python
def order_by(order_by: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ElasticsearchTopMetricsSettings](./object-ElasticsearchTopMetricsSettings.md)
